@@ -1,6 +1,6 @@
 use strict; use warnings;
 package YAML::Any;
-our $VERSION = '0.98';
+our $VERSION = '1.24';
 
 use Exporter ();
 
@@ -29,6 +29,7 @@ my @dump_options = qw(
 my @load_options = qw(
     UseCode
     LoadCode
+    Preserve
 );
 
 my @implementations = qw(
@@ -46,6 +47,7 @@ sub import {
 
 sub Dump {
     no strict 'refs';
+    no warnings 'once';
     my $implementation = __PACKAGE__->implementation;
     for my $option (@dump_options) {
         my $var = "$implementation\::$option";
@@ -58,6 +60,7 @@ sub Dump {
 
 sub DumpFile {
     no strict 'refs';
+    no warnings 'once';
     my $implementation = __PACKAGE__->implementation;
     for my $option (@dump_options) {
         my $var = "$implementation\::$option";
@@ -70,6 +73,7 @@ sub DumpFile {
 
 sub Load {
     no strict 'refs';
+    no warnings 'once';
     my $implementation = __PACKAGE__->implementation;
     for my $option (@load_options) {
         my $var = "$implementation\::$option";
@@ -82,6 +86,7 @@ sub Load {
 
 sub LoadFile {
     no strict 'refs';
+    no warnings 'once';
     my $implementation = __PACKAGE__->implementation;
     for my $option (@load_options) {
         my $var = "$implementation\::$option";
